BlueCelluLab's usage examples
====================================

- Follow the order of examples to understand the library's usage.
- Interactive python notebook files are provided in each example directory.
- The `mechanisms` directory is containing the mod files required for the examples, its compilation instructions is provided in the first tutorial.


.. list-table::
   :header-rows: 1

   * - File Name
     - Description
   * - `singlecell.ipynb <1-singlecell/singlecell.ipynb>`_
     - Demonstration of single cell simulation capabilities
   * - `sonata-network.ipynb <2-sonata-network/sonata-network.ipynb>`_
     - Simulating a group of cells from a multi polulation SONATA circuit
   * - `bpap.ipynb <3-bpap/bpap.ipynb>`_
     - Simulating back propagating action potential in a dendritic tree
   * - `epsp.ipynb <4-epsp/epsp.ipynb>`_
     - Simulating excitatory post synaptic potential on a Hippocampal CA1 cell
   * - Exploring the stimuli available at BlueCelluLab
     - `stimuli.ipynb <5-stimuli/stimuli.ipynb>`_
